__all__ = ['Banshee',
           'Eclipse',
           'ekiga',
           'empathy',
           'epiphany',
           'evince',
           'evolution',
           'gajim',
           'gcalctool',
           'gedit',
           'gnome-documents',
           'gnome-keyring-ask',
           'gnome-panel',
           'gnome-screensaver-dialog',
           'gnome-search-tool',
           'gnome-shell',
           'gnome-window-properties',
           'Instantbird',
           'kwin',
           'Mozilla',
           'notification-daemon',
           'notify-osd',
           'pidgin',
           'rhythmbox',
           'soffice',
           'SeaMonkey',
           'smuxi-frontend-gnome',
           'Thunderbird',
           'xfwm4']
